@@ -800,12 +800,9 @@ def test_surprise_subds(path=None):
     # If subrepo is an adjusted branch, it would have a commit, making most of
     # this test irrelevant because it is about the unborn branch edge case.
     adjusted = somerepo.is_managed_branch()
-    # This edge case goes away with Git v2.22.0.
-    fixed_git = somerepo.git_version >= '2.22.0'
-
     # save non-recursive
     res = ds.save(recursive=False, on_failure='ignore')
-    if not adjusted and fixed_git:
+    if not adjusted:
         # We get an appropriate error about no commit being checked out.
         assert_in_results(res, action='add_submodule', status='error')
 
@@ -814,30 +811,18 @@ def test_surprise_subds(path=None):
     assert_repo_status(subds.path, untracked=['subfile'])
     assert_repo_status(somerepo.path, untracked=['subfile'])
 
-    if adjusted or fixed_git:
-        if adjusted:
-            # adjusted branch: #datalad/3178 (that would have a commit)
-            modified = [subds.repo.pathobj, somerepo.pathobj]
-            untracked = []
-        else:
-            # Newer Git versions refuse to add a sub-repository with no commits
-            # checked out.
-            modified = [subds.repo.pathobj]
-            untracked = ['d1']
+    if adjusted:
+        # adjusted branch: #datalad/3178 (that would have a commit)
+        modified = [subds.repo.pathobj, somerepo.pathobj]
+        untracked = []
+    else:
+        # Newer Git versions refuse to add a sub-repository with no commits
+        # checked out.
+        modified = [subds.repo.pathobj]
+        untracked = ['d1']
         assert_repo_status(ds.path, modified=modified, untracked=untracked)
         assert_not_in(ds.repo.pathobj / 'd1' / 'subrepo' / 'subfile',
                       ds.repo.get_content_info())
-    else:
-        # however, while the subdataset is added (and reported as modified
-        # because it content is still untracked) the subrepo
-        # cannot be added (it has no commit)
-        # worse: its untracked file add been added to the superdataset
-        assert_repo_status(ds.path, modified=['d2/subds'])
-        assert_in(ds.repo.pathobj / 'd1' / 'subrepo' / 'subfile',
-                  ds.repo.get_content_info())
-    # with proper subdatasets, all evil is gone
-    assert_not_in(ds.repo.pathobj / 'd2' / 'subds' / 'subfile',
-                  ds.repo.get_content_info())
 
 
 @with_tree({"foo": ""})
